==> ah-form-builder-sample-0.6.19.tgz: package/es/components/toolbar/EditField.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/components/toolbar/EditField.js";
import React from 'react';
import { connect } from "react-redux";
import TextField from "./field-forms/TextField";
import Checkbox from "./field-forms/Checkbox";
import Content from "./field-forms/Content";
import Date from "./field-forms/Date";
import File from "./field-forms/File";
import Image from "./field-forms/Image";
import List from "./field-forms/List";
import Quiz from "./field-forms/Quiz";
import Select from "./field-forms/Select";
import Signature from "./field-forms/Signature";
import Survey from "./field-forms/Survey";
import Video from "./field-forms/Video";
import Radio from "./field-forms/Radio";
import Section from "./field-forms/Section";

function EditField(props) {
  var _this = this;

  var field = {};

  if (props.newFieldData) {
    field = props.newFieldData;
  } else {
    field = props.data[props.editId];
  }

  var renderFieldForms = function renderFieldForms() {
    switch (field.type) {
      case 'checkbox':
        return /*#__PURE__*/React.createElement(Checkbox, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 29,
            columnNumber: 11
          }
        });

      case 'radio':
        return /*#__PURE__*/React.createElement(Radio, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 33,
            columnNumber: 11
          }
        });

      case 'content':
        return /*#__PURE__*/React.createElement(Content, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 37,
            columnNumber: 13
          }
        });

      case 'date':
        return /*#__PURE__*/React.createElement(Date, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 41,
            columnNumber: 13
          }
        });

      case 'file':
        return /*#__PURE__*/React.createElement(File, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 45,
            columnNumber: 13
          }
        });

      case 'image':
        return /*#__PURE__*/React.createElement(Image, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 49,
            columnNumber: 13
          }
        });

      case 'list':
        return /*#__PURE__*/React.createElement(List, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 53,
            columnNumber: 13
          }
        });

      case 'quiz':
        return /*#__PURE__*/React.createElement(Quiz, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 57,
            columnNumber: 13
          }
        });

      case 'select':
        return /*#__PURE__*/React.createElement(Select, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 61,
            columnNumber: 13
          }
        });

      case 'signature':
        return /*#__PURE__*/React.createElement(Signature, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 65,
            columnNumber: 13
          }
        });

      case 'survey':
        return /*#__PURE__*/React.createElement(Survey, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 69,
            columnNumber: 13
          }
        });

      case 'text':
        return /*#__PURE__*/React.createElement(TextField, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 73,
            columnNumber: 13
          }
        });

      case 'video':
        return /*#__PURE__*/React.createElement(Video, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 77,
            columnNumber: 13
          }
        });

      case 'section':
        return /*#__PURE__*/React.createElement(Section, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 80,
            columnNumber: 16
          }
        });

      default:
        return /*#__PURE__*/React.createElement("div", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 83,
            columnNumber: 11
          }
        }, "Something magical happened");
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "position-relative width-full",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 88,
      columnNumber: 5
    }
  }, renderFieldForms());
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    newFieldData: state.form.newFieldData,
    editId: state.toolbar.editId,
    data: state.form.data
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

export default connect(mapStateToProps, mapDispatchToProps)(EditField);

==> ah-form-builder-sample-0.6.86.tgz: package/es/components/toolbar/EditField.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/components/toolbar/EditField.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { connect } from "react-redux";
import TextField from "./field-forms/TextField";
import Checkbox from "./field-forms/Checkbox";
import Content from "./field-forms/Content";
import Date from "./field-forms/Date";
import File from "./field-forms/File";
import Image from "./field-forms/Image";
import List from "./field-forms/List";
import Quiz from "./field-forms/Quiz";
import Select from "./field-forms/Select";
import Signature from "./field-forms/Signature";
import Survey from "./field-forms/Survey";
import Video from "./field-forms/Video";
import Radio from "./field-forms/Radio";
import Section from "./field-forms/Section";
import _ from 'lodash';

function EditField(props) {
  var _this = this;

  var field = {};

  if (props.newFieldData) {
    field = _.cloneDeep(props.newFieldData);
  } else {
    field = _.cloneDeep(props.data[props.editId]);
    if (field.locals && Object.keys(field.locals).length) Object.keys(field.locals).forEach(function (local) {
      if (local && Object.keys(local).length) field.config = _extends({}, field.config, {}, field.locals[local]);
    });
  }

  var renderFieldForms = function renderFieldForms() {
    switch (field.type) {
      case 'checkbox':
        return /*#__PURE__*/React.createElement(Checkbox, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 35,
            columnNumber: 11
          }
        });

      case 'radio':
        return /*#__PURE__*/React.createElement(Radio, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 39,
            columnNumber: 11
          }
        });

      case 'content':
        return /*#__PURE__*/React.createElement(Content, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 43,
            columnNumber: 13
          }
        });

      case 'date':
        return /*#__PURE__*/React.createElement(Date, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 47,
            columnNumber: 13
          }
        });

      case 'file':
        return /*#__PURE__*/React.createElement(File, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 51,
            columnNumber: 13
          }
        });

      case 'image':
        return /*#__PURE__*/React.createElement(Image, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 55,
            columnNumber: 13
          }
        });

      case 'list':
        return /*#__PURE__*/React.createElement(List, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 59,
            columnNumber: 13
          }
        });

      case 'quiz':
        return /*#__PURE__*/React.createElement(Quiz, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 63,
            columnNumber: 13
          }
        });

      case 'select':
        return /*#__PURE__*/React.createElement(Select, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 67,
            columnNumber: 13
          }
        });

      case 'signature':
        return /*#__PURE__*/React.createElement(Signature, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 71,
            columnNumber: 13
          }
        });

      case 'survey':
        return /*#__PURE__*/React.createElement(Survey, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 75,
            columnNumber: 13
          }
        });

      case 'text':
        return /*#__PURE__*/React.createElement(TextField, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 79,
            columnNumber: 13
          }
        });

      case 'video':
        return /*#__PURE__*/React.createElement(Video, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 83,
            columnNumber: 13
          }
        });

      case 'section':
        return /*#__PURE__*/React.createElement(Section, {
          data: field,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 86,
            columnNumber: 16
          }
        });

      default:
        return /*#__PURE__*/React.createElement("div", {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 89,
            columnNumber: 11
          }
        }, "Something magical happened");
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "position-relative ahfb-width-full",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 94,
      columnNumber: 5
    }
  }, renderFieldForms());
}

var mapStateToProps = function mapStateToProps(state) {
  return {
    newFieldData: state.form.newFieldData,
    editId: state.toolbar.editId,
    data: state.form.data
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {};
};

export default connect(mapStateToProps, mapDispatchToProps)(EditField);
